<?php

/* Plugin Name: Plasso
 * Plugin URI: https://plasso.com
 * Description: Embed a Plasso.com checkout button anywhere on your site using simple shortcodes.
 * Version: 1.1.2
 * Author: Plasso
 * Author URI: https://plasso.com
 * License: GPL-2.0+
 * License URI: http://www.gnu.org/licenses/gpl-2.0.txt
 * GitHub Plugin URI: https://github.com/plasso/wp-plasso
 * Text Domain: plasso
 * Domain Path: /languages/
---------------------------------------------------------------------------------------------------- */


/* Get the Billing Class
---------------------------------------------------------------------------------------------------- */

require_once('plasso-billing.php');


/* Register Plasso Settings
---------------------------------------------------------------------------------------------------- */

function plasso_settings_init() {

	// Plasso settings.
	register_setting('plasso_plugin_page', 'plasso_settings');

	// The protected pages (Forward URL).
	add_settings_field(
		'plasso_select_protected_pages',
		'',
		'',
		'plasso_plugin_page',
		''
	);
}
add_action('admin_init', 'plasso_settings_init');


/* Global Variables
---------------------------------------------------------------------------------------------------- */

// Get the Plasso protected page.
$plasso_options = get_option('plasso_settings');
$plasso_protected = $plasso_options['plasso_select_protected_pages'];


/* Plasso Protect Always Set
---------------------------------------------------------------------------------------------------- */

// If the protected page has not been set.
if($plasso_protected == null) {

	// Define the Plasso forward page.
	$plasso_protected_page = get_page_by_title('Plasso Forward Page', OBJECT, 'page');

	// If the Plasso forward page exists ...
	if(isset($plasso_protected_page)) {
		$plasso_protected_page_id = $plasso_protected_page->ID;
	} else {
		wp_insert_post(array(
			'post_type' => 'page',
			'post_title' => 'Plasso Forward Page',
			'post_content' => 'If you’re using a Plasso Storefront or Billing space, you can set a Forward URL users will be redirected to after they finish checking out or logging in. This page is protected and can only be viewed by your customers. We’ve created and set this as your current Forward URL page, but you can choose any page you like from the Plasso plugin options page (feel free to delete this page at any time).',
			'post_name' => 'plasso-forward',
			'post_status' => 'publish',
			'import_id' => 918550,
		));

		// Define the Plasso forward page.
		$plasso_protected_page_id = '918550';
	}

	// Set the protected page.
	$plasso_defaults = array(
    'plasso_select_protected_pages' => $plasso_protected_page_id,
  );
  wp_parse_args(update_option('plasso_settings', $plasso_defaults));
}


/* Plasso Protect Always Set
---------------------------------------------------------------------------------------------------- */

function plasso_protect_pages() {

	// Get the Plasso protected page.
	global $plasso_protected;

	// If we are on the selected protected page.
	if(is_page($plasso_protected)) {
		$plassoBilling = new PlassoBilling((isset($_GET['__logout']))?'logout':(isset($_GET['_plasso_token'])?$_GET['_plasso_token']:NULL));
	}
}
add_action('template_redirect','plasso_protect_pages');


/* The [plasso] Shortcode
---------------------------------------------------------------------------------------------------- */

// Function to display the actual button.
function plasso_button($args) {

	$url = 'https://plasso.com/s/' . $args['id'];

	if(isset($args['preselect'])) {
		$url = 'https://plasso.com/s/' . $args['id'] . '?preselect=' . $args['preselect'];
	}

	if($args['view'] == 'login') {
		$url = 'https://plasso.com/s/' . $args['id'] . '/login';
	}

	return '<a href="' . $url . '" ' . 'class="plo-button ' . esc_attr($args['class']) . '" data-overlay-color="' . esc_attr($args['overlay']) . '">' . esc_html($args['text']) . '</a>';
}

// Load the Plasso embed script.
function plasso_load_js() {
	wp_enqueue_script('plasso-overlay-script', 'https://plasso.com/embed/v3/e.js', array(), null, true);
}
add_action('wp_enqueue_scripts', 'plasso_load_js');

// Load the Plasso button css.
function plasso_load_css() {
	wp_enqueue_style('plasso-button-styles', plugin_dir_url(__FILE__) . 'assets/styles/plasso-button.css', array(), null, false);
}

// Function to process the [plasso] shortcode.
add_shortcode('plasso', 'plasso_shortcode');
function plasso_shortcode($attr) {

	// Default shortcode values.
	$defaults = array(
		'view' => '',
		'id' => 'zZ2NwPCfyU',
		'class' => 'plasso-button',
		'text' => 'Buy Something',
		'overlay' => ''
	);

	extract(shortcode_atts($defaults, $attr));

	// Load the plasso button styles.
	plasso_load_css();

	$attr = array_merge($defaults, $attr);

	if(!empty($id)) {
		$html = plasso_button($attr);

		$before_html = '';
		$after_html  = '';

		$before_html = apply_filters('plasso_shortcode_before', $before_html);
		$html = apply_filters('plasso_shortcode_html', $html);
		$after_html = apply_filters('plasso_shortcode_after', $after_html);

		return $before_html . $html . $after_html;
	}
}


/* Make the Plasso TinyMCE Button
---------------------------------------------------------------------------------------------------- */

// Enqueue the MCE button script.
add_filter("mce_external_plugins", "enqueue_plasso_mce_button_script");
function enqueue_plasso_mce_button_script($plugin_array) {

	// Enqueue the Plasso TinyMCE plugin script with its ID.
	$plugin_array["plasso_button_plugin"] =  plugin_dir_url(__FILE__) . "assets/scripts/plasso-mce-button.js";
	return $plugin_array;
}

// Register the Plasso MCE button.
add_filter("mce_buttons", "register_plasso_mce_button");
function register_plasso_mce_button($buttons) {

	//register buttons with their id.
	array_push($buttons, "plasso");
	return $buttons;
}

// Register the Plasso MCE text button.
add_action("admin_print_footer_scripts", "register_plasso_text_button");
function register_plasso_text_button() {
	if(wp_script_is("quicktags")) { ?>
		<script type="text/javascript">

			// Retrieve the selected text from the text editor.
			function getSel() {
				var txtarea = document.getElementById("content");
				var start = txtarea.selectionStart;
				var finish = txtarea.selectionEnd;
				return txtarea.value.substring(start, finish);
			}

			QTags.addButton(
				"plasso_shortcode",
				"plasso",
				callback
			);

			function callback() {
				var selected_text = getSel();
				QTags.insertContent('[plasso type="storefront" id="SpaceID" text="Buy Something"]');
			}
		</script>
	<?php }
}


/* The Options Page
---------------------------------------------------------------------------------------------------- */

// Add the Plasso options page/link to the WordPress admin.
add_action('admin_menu', 'plasso_add_admin_menu');
function plasso_add_admin_menu() {
	add_menu_page(
		'Plasso',
		'Plasso',
		'manage_options',
		'plasso',
		'plasso_options_page',
    plugin_dir_url( __FILE__ ) . 'assets/images/plasso-icon.png'
	);
}

// Enqueue Plasso admin scripts and styles.
function plasso_admin_css() {
  wp_register_style('plasso_admin_css', plugin_dir_url(__FILE__) . 'assets/styles/plasso-admin.css', false, '1.0.0');
  wp_enqueue_style('plasso_admin_css');
}
add_action('admin_enqueue_scripts', 'plasso_admin_css');

function plasso_admin_js() {
  wp_register_script('plasso_admin_js', plugin_dir_url(__FILE__) . 'assets/scripts/plasso-admin.js', false, '1.0.0');
  wp_enqueue_script('plasso_admin_js');
}
add_action('admin_enqueue_scripts', 'plasso_admin_js');

// Fix the options page icon.
add_action('admin_head', 'plasso_options_page_icon');
function plasso_options_page_icon() { ?>
  <style>
		#toplevel_page_plasso .wp-menu-image img {
			width: 16px;
		}
  </style>
<?php }

// Render the settings page for this plugin.
function plasso_options_page() {

	// Define "Options".
	global $plasso_options;

	?>
	<div class="wrap" id="plasso">
		<svg xmlns="http://www.w3.org/2000/svg" width="0" height="0" display="none">
		  <symbol id="svg_plasso_logo" viewBox="0 0 389.9292 73.0132"><path d="M1.21,1.3101h19.2618c8.3691,0,15.2275,0.8071,20.4716,4.1347c6.9571,4.2364,10.8912,11.7998,10.8912,21.379 c0,18.1503-13.3125,25.1113-31.3628,25.1113h-4.1343v18.4541c0,0.8086-0.4043,1.2099-1.21,1.2099H1.21 c-0.8071,0-1.21-0.4013-1.21-1.2099V2.5215C0,1.7144,0.4028,1.3101,1.21,1.3101z M34.9927,26.5215 c0-8.269-4.8399-11.2939-14.521-11.2939h-4.1343v22.5893h4.0342C30.355,37.8169,34.9927,34.69,34.9927,26.5215z"></path><path d="M63.1474,1.21h14.4205c0.8056,0,1.2099,0.4028,1.2099,1.2099V56.978h26.5215c0.8071,0,1.21,0.4014,1.21,1.21v12.2012 c0,0.8086-0.4029,1.2099-1.21,1.2099H63.1474c-0.8071,0-1.2114-0.4013-1.2114-1.2099V2.4199 C61.936,1.6128,62.3403,1.21,63.1474,1.21z"></path><path d="M200.7593,61.4136c-0.503-0.6055-0.4014-1.21,0.1015-1.7158c2.7227-2.9239,5.6485-5.9483,8.4697-8.8711 c0.6045-0.6055,1.21-0.5059,1.7129,0.1015c4.1358,5.1397,8.7754,8.1641,14.7227,8.1641c5.6484,0,9.2783-3.0244,9.2783-7.1572 c0-6.6553-4.4355-6.7569-13.0098-10.2852c-11.291-4.6406-18.1494-9.1777-18.1494-20.5732C203.8852,9.0762,212.8579,0,226.6772,0 c8.167,0,14.7227,2.4199,20.0655,8.0669c0.5029,0.5044,0.5029,1.1094,0,1.7144c-2.3184,2.9243-4.7383,5.7485-7.0557,8.6733 c-0.5068,0.605-1.1113,0.605-1.7158,0c-3.2256-3.3271-6.7569-4.8413-10.5879-4.8413c-4.4385,0-7.3613,2.6221-7.3613,6.0513 c0,4.5371,3.831,6.1513,10.081,8.269c13.4141,4.437,20.9766,9.2778,20.9766,22.689c0,13.9179-10.1826,22.3906-25.4121,22.3906 C214.4761,73.0132,206.6079,68.6763,200.7593,61.4136z"></path><path d="M257.1235,61.4136c-0.5039-0.6055-0.4014-1.21,0.1016-1.7158c2.7226-2.9239,5.6484-5.9483,8.4697-8.8711 c0.6045-0.6055,1.21-0.5059,1.7129,0.1015c4.1357,5.1397,8.7754,8.1641,14.7227,8.1641c5.6484,0,9.2783-3.0244,9.2783-7.1572 c0-6.6553-4.4356-6.7569-13.0098-10.2852c-11.291-4.6406-18.1494-9.1777-18.1494-20.5732C260.2495,9.0762,269.2221,0,283.0415,0 c8.167,0,14.7226,2.4199,20.0654,8.0669c0.5029,0.5044,0.5029,1.1094,0,1.7144c-2.3183,2.9243-4.7383,5.7485-7.0556,8.6733 c-0.5069,0.605-1.1114,0.605-1.7168,0c-3.2256-3.3271-6.7559-4.8413-10.587-4.8413c-4.4384,0-7.3613,2.6221-7.3613,6.0513 c0,4.5371,3.8311,6.1513,10.0811,8.269c13.414,4.437,20.9765,9.2778,20.9765,22.689c0,13.9179-10.1826,22.3906-25.4121,22.3906 C270.8393,73.0132,262.9721,68.6763,257.1235,61.4136z"></path><path d="M315.9067,36.5049C315.9067,15.9331,332.7505,0,352.9184,0c20.2696,0,37.0108,15.9331,37.0108,36.5049 c0,20.6743-16.7412,36.5083-37.0108,36.5083C332.4477,73.0132,315.9067,56.8765,315.9067,36.5049z M372.7866,36.5049 c0-12.2012-8.1699-21.8823-19.8682-21.8823c-11.7998,0-19.9677,9.5791-19.9677,21.8823c0,12.4048,7.9668,21.8833,19.9677,21.8833 C364.7182,58.3882,372.7866,48.8081,372.7866,36.5049z"></path><path d="M154.8457,22.6382c3.5639,5.3057,8.125,12.8198,13.5625,23.2529c0.9658,1.8594,1.8345,3.5879,2.6221,5.1934 c-4.8311-0.7734-10.2413-1.2588-16.2071-1.2588c-5.9673,0-11.3779,0.4854-16.2041,1.2588c0.7818-1.6055,1.6548-3.334,2.6206-5.1875 C146.6426,35.5166,151.2324,27.9873,154.8457,22.6382 M154.4204,0.1753c-2.0068,1.7881-11.4229,11.0479-25.9736,38.9893 c-13.3511,25.6631-11.7339,32.0449-10.6392,33.54c0.2544,0.3467,0.7144,0.2725,1.1724-0.0029 c2.9648-1.7676,15.3759-8.3623,35.8432-8.3623c0.0073,0,0.0088,0,0.0117,0c20.4717,0,32.8858,6.6006,35.8418,8.3623 c0.4566,0.2724,0.9537,0.3652,1.2471,0.0029c1.1665-1.4531,2.7437-7.6641-10.7261-33.54 c-14.7348-28.3008-23.8755-37.1939-25.9282-38.9683C154.9712-0.06,154.6885-0.063,154.4204,0.1753z"></path></symbol>
		  <symbol id="svg_membership" viewBox="0 0 24 19.998"><path fill-rule="evenodd" clip-rule="evenodd" d="M21.5,0h-19C1.1211,0,0,1.1216,0,2.5v14.998c0,1.3784,1.1211,2.5,2.5,2.5h19c1.3789,0,2.5-1.1216,2.5-2.5 V2.5C24,1.1216,22.8789,0,21.5,0z M5.5078,9.7954C5.5,9.7767,5.4932,9.7567,5.4858,9.7378 c-0.0425,0.0078-0.0854,0.0123-0.127,0.0123c-0.0649,0-0.0098-0.0116-0.0596-0.0421C5.0776,9.5735,4.8267,8.5837,4.8223,8.2267 C4.8169,7.7796,5.126,7.9998,5.1895,7.9998c0.0122,0,0.0195,0.0013,0.0195,0.0013s0.0098-0.0024,0.0225-0.0057 c-0.001-0.042-0.0034-0.0841-0.0034-0.126c0-0.5023-0.2153-1.3087-0.0869-1.7515c0.1982-0.6862,0.4375-1.4423,0.9658-1.4425 c0.5034-0.5647,1.3833-0.6609,1.9834-0.6609c0.3105,0,0.5464,0.0258,0.6167,0.0258c0.2969,0,1.0449,0.4514,1.561,0.9804 c0.3633,0.3728,0.3228,0.4053,0.5225,1.0927c0.1318,0.455-0.0859,1.2725-0.0859,1.756c0,0.0427-0.0024,0.0854-0.0034,0.1281 c0.0083,0.0021,0.0142,0.0037,0.0142,0.0037s0.0073-0.0013,0.0195-0.0013c0.0635,0,0.3716-0.2268,0.3667,0.2203 c-0.0039,0.357-0.2554,1.3534-0.4771,1.4879c-0.0493,0.0303,0.0063,0.0421-0.0591,0.0421c-0.0386,0-0.0791-0.0042-0.1187-0.0111 c-0.0068,0.0173-0.0137,0.0354-0.0205,0.0525c-0.4751,1.1718-0.5166,1.4839-1.1436,2.2179c0,1.7572,0.937,1.7551,1.4541,1.889 c0.2769,0.0718,0.5005,0.1293,0.7017,0.1848c-0.4141,0.5611-0.5098,1.2797-0.4229,1.8092 c0.0024,0.0145,0.0093,0.0275,0.0122,0.0419c-0.8472,0.0303-1.9219,0.0351-3.103,0.0351c-2.5254,0-4.5469,0.0244-4.834-0.2481 c-0.2871-0.2725,0.2417-1.0104,0.5166-1.2715c0.2754-0.2612,0.731-0.3331,1.5054-0.5513c0.6118-0.1724,1.5327-0.1541,1.5327-1.8847 C6.124,11.3445,5.9878,10.9766,5.5078,9.7954z M12.0024,15.7303c0,0-0.2056-1.2509,0.9551-1.4771 c0.8413-0.1639,0.8555-0.2518,2.0679-0.7861c0.1509-0.218,0.2983-0.5969,0.4131-1.024c-0.0142,0.0054-0.2573,0.3913-0.2573,0.3913 h-0.0054c-0.0161-0.0033-0.1797-0.0386-0.27-0.0485c-0.0513-0.0057-0.874-0.1025-1.1562-0.1025c0,0-0.0049,0-0.0073,0 c-0.0356,0.0002-0.6787,0.0053-0.8354,0.0777l0.8936-1.6917c0,0-0.082,0.1321-0.2021,0.1321c-0.0449,0-0.0952-0.0184-0.1484-0.0687 c-0.0889-0.084-0.1997-0.1069-0.2944-0.1069c-0.1147,0-0.2061,0.0336-0.2061,0.0336c-0.1221-1.3198-0.0225-4.6086,1.4297-5.6046 c0.5063-0.3472,0.937-0.4696,1.2935-0.4696c0.3779,0,0.6714,0.1379,0.8813,0.2911c0.21-0.1533,0.5034-0.2911,0.8813-0.2911 c0.356,0.0001,0.7871,0.1224,1.2935,0.4696c1.4717,1.0095,1.4761,4.3175,1.3076,5.6194c0,0-0.0601-0.0218-0.1489-0.0218 c-0.0806,0-0.1851,0.0179-0.29,0.0863c-0.0728,0.0473-0.1362,0.0646-0.1895,0.0646c-0.146,0-0.2202-0.1288-0.2231-0.1339 c0.0103,0.0184,0.9165,1.6359,0.9307,1.6717c-0.0679-0.0273-0.3115-0.0339-0.541-0.0339c-0.2158,0-0.4194,0.0059-0.4531,0.0059 c-0.2554,0-0.9092,0.1012-0.957,0.1066c-0.0908,0.0099-0.1724,0.0146-0.2461,0.0146c-0.0337,0-0.2202-0.3708-0.251-0.3726 c0.127,0.4933,0.3135,0.895,0.3794,0.9949c1.2109,0.5271,1.2759,0.6287,1.9712,0.7936c1.1641,0.276,0.9614,1.48,0.9614,1.48 s-0.5059,0.2529-4.4814,0.2529S12.0024,15.7303,12.0024,15.7303z"></path></symbol>
		  <symbol id="svg_storefront" viewBox="0 0 23.9853 21.9824"><path fill-rule="evenodd" clip-rule="evenodd" d="M22.4346,2.9775L4.6333,1.9914L4.2598,0.4131C4.2583,0.4075,4.2544,0.4034,4.2529,0.3979 C4.2046,0.1724,4.0137,0,3.7734,0H0.5C0.2236,0,0,0.2236,0,0.5S0.2236,1,0.5,1h2.8716l3.8662,16.339 c-0.7324,0.4359-1.23,1.2287-1.23,2.1434c0,1.3789,1.1182,2.5,2.4922,2.5s2.4922-1.1211,2.4922-2.5 c0-0.5651-0.1948-1.0809-0.5112-1.5h7.0381c-0.3164,0.4191-0.5112,0.9349-0.5112,1.5c0,1.3789,1.1182,2.5,2.4922,2.5 s2.4922-1.1211,2.4922-2.5s-1.1182-2.5-2.4922-2.5h-11c-0.1069,0-0.209,0.0185-0.312,0.0316l-0.7251-3.0644l14.0215-0.9672 c0.5303-0.0801,1.2217-0.3984,1.5049-1.459c0.1436-0.5391,0.8877-5.8379,0.9727-6.4492 C24.1084,3.8799,23.5635,3.1172,22.4346,2.9775z M9.9922,19.4824c0,0.8271-0.6689,1.5-1.4922,1.5s-1.4922-0.6729-1.4922-1.5 s0.6689-1.5,1.4922-1.5S9.9922,18.6553,9.9922,19.4824z M20.9922,19.4824c0,0.8271-0.6689,1.5-1.4922,1.5s-1.4922-0.6729-1.4922-1.5 s0.6689-1.5,1.4922-1.5S20.9922,18.6553,20.9922,19.4824z"></path></symbol>
		  <symbol id="svg_billing" viewBox="0 0 23.4027 19.9966"><g><path fill-rule="evenodd" clip-rule="evenodd" d="M7.9445,8.1123c0.2129,1.6348,1.5508,2.4644,3.8203,2.4092c2.3936-0.0737,2.626,0.9033,2.7305,1.3687 l0.0293,0.1235c0.0039,0.0132,0.2432,1.3838-1.667,1.8955c-1.4473,0.3892-2.3301,0.043-2.6162-1.0264 c-0.0723-0.2671-0.3428-0.4253-0.6133-0.3535c-0.2666,0.0713-0.4248,0.3457-0.3535,0.6123 c0.1357,0.5044,0.6846,1.9189,2.5605,1.9189c0.2217,0,0.4683-0.0276,0.7285-0.071l0.2949,1.0999 c0.0605,0.2236,0.2627,0.3706,0.4834,0.3706c0.043,0,0.0859-0.0054,0.1299-0.0171c0.2666-0.0713,0.4248-0.3457,0.3535-0.6123 l-0.2964-1.106c1.8687-0.7017,2.1494-2.2703,1.9419-3.0532c-0.123-0.5522-0.5127-2.2202-3.7314-2.1499 c-2.6201,0.0737-2.752-1.1411-2.8027-1.5381c-0.002-0.0142-0.0996-1.4321,1.7646-1.9321c1.7412-0.4639,2.3457,0.3491,2.5498,1.1147 c0.0732,0.2671,0.3447,0.4258,0.6133,0.3535c0.2666-0.0713,0.4248-0.3457,0.3535-0.6123c-0.1572-0.5839-0.8442-2.358-3.2998-1.9264 l-0.293-1.0931c-0.0723-0.2671-0.3428-0.4248-0.6133-0.3535C9.7453,3.6055,9.5871,3.8799,9.6584,4.1465l0.2993,1.1171 C8.1378,5.9893,7.8742,7.5682,7.9445,8.1123z"></path> <path fill-rule="evenodd" clip-rule="evenodd" d="M23.2931,6.2451c-0.1133-0.1426-0.29-0.2129-0.4775-0.1802l-1.8301,0.3224 C19.5382,2.6564,15.9191,0,11.6837,0c-3.7139,0-7.0986,2.042-8.834,5.3291C2.7209,5.5732,2.8146,5.876,3.0587,6.0049 c0.2422,0.1274,0.5459,0.0366,0.6758-0.209C5.2951,2.8379,8.342,1,11.6837,1c3.7427,0,6.9546,2.3021,8.3027,5.5634l-1.8604,0.3278 c-0.1826,0.0322-0.333,0.1631-0.3896,0.3398s-0.0098,0.3706,0.1201,0.5029l3.0479,3.0977 c0.0947,0.0967,0.2236,0.1494,0.3564,0.1494c0.0312,0,0.0635-0.0029,0.0947-0.0093c0.1641-0.0312,0.3018-0.1436,0.3662-0.2979 L23.3634,6.75C23.4347,6.5815,23.4074,6.3877,23.2931,6.2451z"></path> <path fill-rule="evenodd" clip-rule="evenodd" d="M20.3449,13.9917c-0.2412-0.1265-0.5459-0.0361-0.6758,0.209c-1.5605,2.958-4.6074,4.7959-7.9492,4.7959 c-3.7427,0-6.9551-2.302-8.3032-5.5632l1.8599-0.3279c0.1826-0.0322,0.333-0.1631,0.3896-0.3398s0.0098-0.3706-0.1201-0.5029 L2.4992,9.165C2.382,9.0454,2.2121,8.9927,2.048,9.0244S1.7462,9.168,1.6818,9.3228l-1.6426,3.9243 c-0.0713,0.1685-0.0439,0.3623,0.0703,0.5049c0.0957,0.1201,0.2402,0.188,0.3906,0.188c0.0283,0,0.0576-0.0024,0.0869-0.0078 l1.8301-0.3226c1.4473,3.7307,5.0664,6.3871,9.3027,6.3871c3.7139,0,7.0986-2.042,8.834-5.3291 C20.6828,14.4233,20.589,14.1206,20.3449,13.9917z"></path></g></symbol>
		  <symbol id="svg_fundraise" viewBox="0 0 23.9933 22.0127"><g><path fill-rule="evenodd" clip-rule="evenodd" d="M23.9928,15.4514c0-0.0068,0.0005-0.012,0.0005-0.0188c0-0.0285-0.0005-0.0511-0.0005-0.0792 l-0.0005-3.8876c-0.002-0.03-0.0112-0.0517-0.0146-0.0805V9.5c0-0.2764-0.2236-0.5-0.5-0.5h-1.5078 c-0.2236,0-0.4209,0.1484-0.4814,0.3643c-0.0078,0.0291-0.0884,0.326-0.1831,0.9279c-0.5923,0.252-1.3018,0.5961-1.6206,0.7684 c-0.2295,0.1248-0.7065,0.4301-1.0166,0.8764c-0.0723,0.0168-0.1445,0.0466-0.2168,0.0582 c-0.1855,0.0234-0.2822-0.0635-0.5479-0.2354c-0.4521-0.293-1.0723-0.6953-2.4121-0.7539 c-1.8057-0.0703-3.1738,0.7852-4.0947,1.3545c-0.2012,0.125-0.3799,0.2363-0.5342,0.3174l-0.3018,0.1592 c-1.04,0.5547-1.9385,1.0332-3.4443,1.0879c-0.6221,0.0225-1.0557,0.4961-1.0791,1.1777 c-0.0137,0.3711,0.0996,0.8105,0.3535,1.2314c-0.6543-0.3018-1.083-0.6592-1.5039-1.0117l-0.2227-0.1846 c-1.918-1.5713-3.5742-1.4268-4.3037-0.627c-0.5029,0.5518-0.4814,1.3135,0.0762,1.876c1.3037,1.3193,5.9258,5.626,10.6309,5.626 c1.8672,0,4.4502-0.9443,6.1592-1.5693c0.5234-0.1914,1.1133-0.4072,1.2979-0.4424l0.0654,0.0013 C18.7882,20.4232,19.1788,21,19.923,21h1.4785c0.0825,0.4155,0.1465,0.6263,0.1543,0.6504C21.6212,21.8584,21.8146,22,22.0323,22 h1.4453c0.2764,0,0.5-0.2236,0.5-0.5v-1.8454c0.0054-0.0515,0.0156-0.1017,0.0156-0.1546L23.9928,15.4514z M19.3937,12.668 c0.083-0.2314,0.3906-0.5244,0.7676-0.7285c0.2397-0.1297,0.6196-0.3151,0.9976-0.4893c-0.0986,0.9686-0.1812,2.2947-0.1812,4.044 c0,2.0392,0.126,3.5104,0.2607,4.5059H19.923c-0.0693,0-0.2812,0-0.5381-0.6914c-0.0049-0.0117-0.4619-1.1494-0.4619-3.251 C18.923,13.9434,19.3859,12.6895,19.3937,12.668z M16.8829,19.5039c-1.543,0.5645-4.125,1.5088-5.8154,1.5088 c-4.3174,0-8.6846-4.0791-9.9443-5.3535c-0.1963-0.1982-0.1211-0.3682-0.0234-0.4756c0.1348-0.1484,0.3906-0.2578,0.7441-0.2578 c0.5322,0,1.2861,0.248,2.1855,0.9854l0.2158,0.1787c0.8809,0.7363,1.8789,1.5703,4.5957,1.877 c1.1934,0.1396,4.4482-0.8398,4.8154-0.9512c0.2637-0.0801,0.4121-0.3584,0.334-0.6221c-0.0791-0.2637-0.3516-0.4121-0.6211-0.3359 c-1.2646,0.373-3.4902,0.9463-4.1221,0.873c-1.6953-0.1816-2.2285-1.3066-2.2109-1.793c0.0068-0.209,0.0801-0.2119,0.1162-0.2129 c1.7363-0.0635,2.7764-0.6182,3.8789-1.2051l0.2959-0.1572c0.1729-0.0908,0.3721-0.2129,0.5957-0.3516 c0.8652-0.5361,2.0527-1.2832,3.5254-1.2051c1.0674,0.0459,1.5156,0.3369,1.9111,0.5928c0.2554,0.1662,0.5166,0.3292,0.9058,0.374 c-0.1533,0.6241-0.3423,1.6752-0.3423,3.085c0,1.3884,0.1836,2.3873,0.3354,2.9812 C17.9899,19.1028,17.5826,19.2484,16.8829,19.5039z"></path><path fill-rule="evenodd" clip-rule="evenodd" d="M7.503,10c2.4814,0,4.5-2.2432,4.5-5s-2.0186-5-4.5-5s-4.5,2.2432-4.5,5S5.0216,10,7.503,10z M7.503,1 c1.9297,0,3.5,1.7939,3.5,4s-1.5703,4-3.5,4s-3.5-1.7939-3.5-4S5.5734,1,7.503,1z"></path><path fill-rule="evenodd" clip-rule="evenodd" d="M7.4698,6.9932c0.2764,0,0.5-0.2236,0.5-0.5v-3c0-0.2764-0.2236-0.5-0.5-0.5s-0.5,0.2236-0.5,0.5v3 C6.9698,6.7695,7.1935,6.9932,7.4698,6.9932z"></path></g></symbol>
		  <symbol id="svg_payme" viewBox="0 0 48 48"><path d="M24,0A24,24,0,1,0,48,24,24,24,0,0,0,24,0ZM38.59,40.42c-2.35-.64-4.44-1.31-6.22-2l-0.48-.17c-1.28-.43-3-1-3.11-4.81a15.21,15.21,0,0,0,2.59-5l0.49-1.3a1,1,0,0,0,.59-0.43c1.07-1.07,1.61-4.41,1.62-5.19a1.8,1.8,0,0,0-.68-1.63A1.32,1.32,0,0,0,33,19.7c0-.33.08-0.7,0.13-1.07a10.72,10.72,0,0,0,0-3.83l-0.23-.85A5.1,5.1,0,0,0,31.38,11c-1.48-1.6-3.92-3.32-5.27-3.32l-0.27,0c-0.35,0-.88-0.06-1.53-0.06-2.8,0-4.9.69-6.25,2.07-2,.38-2.74,3.09-3.29,5.1a10.56,10.56,0,0,0,0,3.75c0,0.4.1,0.78,0.13,1.14a1.32,1.32,0,0,0-.47.21,1.82,1.82,0,0,0-.67,1.63c0,0.8.58,4.3,1.71,5.25a0.92,0.92,0,0,1-.26-0.57,1,1,0,0,0,.26.58l0,0.05a1.21,1.21,0,0,0,.47.29l0,0.07a23.47,23.47,0,0,0,3,6.23C19,37.11,17.7,37.58,16,38.16l-0.75.27c-1.7.67-3.69,1.32-5.91,2A22,22,0,1,1,38.59,40.42ZM15.53,26.8h0Z"></path></symbol>
		  <symbol id="svg_invoice" viewBox="0 0 20 23.998"><g><path fill-rule="evenodd" clip-rule="evenodd" d="M19.8535,4.1426l-3.998-3.9961C15.7617,0.0527,15.6348,0,15.502,0H1.5C0.6729,0,0,0.6729,0,1.5v20.998 c0,0.8271,0.6729,1.5,1.5,1.5h17c0.8271,0,1.5-0.6729,1.5-1.5V4.4961C20,4.3633,19.9473,4.2363,19.8535,4.1426z M18.5,22.998h-17 c-0.2754,0-0.5-0.2241-0.5-0.5V1.5C1,1.2241,1.2246,1,1.5,1h13.5049v3.501c0,0.2764,0.2236,0.5,0.5,0.5H19V22.498 C19,22.7739,18.7754,22.998,18.5,22.998z"></path><path fill-rule="evenodd" clip-rule="evenodd" d="M17.001,10.999V9.5244c0-0.2764-0.2236-0.5-0.5-0.5H3.4756c-0.2764,0-0.5,0.2236-0.5,0.5v1.4746H17.001z"></path><path fill-rule="evenodd" clip-rule="evenodd" d="M10.998,11.999H2.9756v8.52c0,0.2764,0.2236,0.5,0.5,0.5h7.5225V11.999z"></path><path fill-rule="evenodd" clip-rule="evenodd" d="M11.998,11.999v9.02h4.5029c0.2764,0,0.5-0.2236,0.5-0.5v-8.52H11.998z"></path><rect x="9" y="4.999" fill-rule="evenodd" clip-rule="evenodd" width="2" height="1"></rect><rect x="9" y="2.999" fill-rule="evenodd" clip-rule="evenodd" width="4" height="1"></rect><path fill-rule="evenodd" clip-rule="evenodd" d="M3.5039,7.022h3c0.2764,0,0.5-0.2236,0.5-0.5v-3c0-0.2764-0.2236-0.5-0.5-0.5h-3 c-0.2764,0-0.5,0.2236-0.5,0.5v3C3.0039,6.7983,3.2275,7.022,3.5039,7.022z"></path></g></symbol>
		  <symbol id="svg_recurring" viewBox="0 0 48.0386 52.9277"><path fill-rule="evenodd" clip-rule="evenodd" d="M47.7997,30.0772c-0.7597,4.6847-3.6781,8.703-7.5106,11.5487 c-3.4126,2.5287-7.5697,4.1528-11.7419,4.4878l8.0669,4.7569c0.5218,0.3085,0.6973,0.9849,0.391,1.5112 c-0.3066,0.526-0.9793,0.7025-1.5011,0.394l-11.7985-6.9581c-0.0044-0.0024-0.0066-0.0075-0.0096-0.0099 c-0.1372-0.0826-0.2487-0.193-0.3375-0.3229c-0.0237-0.0355-0.0334-0.077-0.0527-0.1154c-0.0535-0.1007-0.0941-0.2039-0.1145-0.3183 c-0.0033-0.0212-0.0193-0.0382-0.0215-0.0598c-0.0053-0.0422,0.014-0.0813,0.014-0.123c0-0.0603-0.0162-0.1175-0.0066-0.1789 c0.0066-0.04,0.0301-0.0709,0.0408-0.1091c0.0172-0.0629,0.0387-0.1186,0.0665-0.1775c0.0428-0.0921,0.0964-0.1725,0.1607-0.2476 c0.0245-0.028,0.0331-0.0656,0.0599-0.0914l9.9236-9.4698l0.0011,0.0002c0.4393-0.4193,1.1336-0.4006,1.5503,0.0422 c0.4158,0.4423,0.3976,1.1411-0.0417,1.5602l-8.1397,7.766c0.0621,0.0007,0.12,0.0144,0.181,0.0144 c4.1487,0.0042,8.5362-1.548,12.0065-4.1285c3.4779-2.5806,6.0108-6.1528,6.6482-10.1243c0.1427-0.89,0.21-1.7742,0.2111-2.6476 c0-7.9109-5.7021-14.8901-13.7121-16.1939c-0.599-0.0972-1.005-0.6638-0.9086-1.2658c0.0965-0.602,0.6589-1.0114,1.258-0.9143 c9.0887,1.4847,15.5559,9.3896,15.5559,18.374C48.0397,28.0658,47.9616,29.0684,47.7997,30.0772z M24.8648,8.2388 c-0.0066,0.0401-0.0301,0.0713-0.0409,0.1097c-0.0171,0.0616-0.0386,0.1166-0.0653,0.1742 c-0.0439,0.0937-0.0975,0.1747-0.1629,0.2509c-0.0234,0.0274-0.032,0.0645-0.0588,0.0897l-9.9236,9.4697h0.0011 c-0.4404,0.4199-1.1347,0.4015-1.5525-0.041c-0.4169-0.4426-0.3987-1.1417,0.0417-1.5615l8.1386-7.7661 c-0.0621-0.0006-0.12-0.0143-0.1821-0.0143c-4.1507-0.0042-8.5382,1.5478-12.0087,4.1282 C5.5737,15.659,3.0419,19.231,2.4076,23.2042c-0.1435,0.8906-0.2133,1.7746-0.2144,2.646c0,7.9111,5.7001,14.8897,13.7176,16.1944 c0.5979,0.0976,1.0038,0.6647,0.9064,1.2667c-0.0963,0.602-0.66,1.0107-1.2577,0.9131C6.465,42.7395,0,34.8344,0,25.8502 c-0.0011-0.9909,0.0794-1.9934,0.2422-2.9996c0.7575-4.6852,3.6739-8.7037,7.5065-11.5493c3.4134-2.5297,7.5718-4.1535,11.746-4.488 L11.43,2.0567c-0.5229-0.308-0.6995-0.984-0.3932-1.5102c0.3065-0.5261,0.9782-0.7032,1.5011-0.3951l11.7987,6.958 c0.0042,0.0024,0.0064,0.0073,0.0105,0.01c0.1361,0.0828,0.2497,0.1936,0.3375,0.3241c0.0226,0.0327,0.0301,0.0709,0.0483,0.106 c0.0557,0.1034,0.0985,0.21,0.1178,0.3278c0.0044,0.0207,0.0193,0.0373,0.0215,0.0585c0.0042,0.0415-0.014,0.0799-0.014,0.1214 C24.8582,8.1184,24.8744,8.1763,24.8648,8.2388z"></path></symbol>
		  <symbol id="svg_checkmark" viewBox="0 0 47.9999 48.0002"><path fill-rule="evenodd" clip-rule="evenodd" d="M24.0004,48.0002C10.7454,47.9992,0,37.2551,0,24.0001 C0,10.7447,10.7454,0.0005,24.0004,0c13.2542,0.0005,23.9995,10.7447,23.9995,24.0001 C47.9999,37.2551,37.2546,47.9992,24.0004,48.0002z M39.5563,8.4436C35.5718,4.4609,30.0778,2.0005,24.0004,2 C17.9221,2.0005,12.428,4.4609,8.4436,8.4436C4.461,12.4279,2,17.9218,1.999,24.0001C2,30.078,4.461,35.5719,8.4436,39.5561 c3.9844,3.9828,9.4785,6.4432,15.5568,6.4441c6.0774-0.0009,11.5714-2.4613,15.5559-6.4441 c3.9824-3.9842,6.4435-9.4781,6.4445-15.556C45.9998,17.9218,43.5387,12.4279,39.5563,8.4436z M19.7063,33.7347 c-0.3906,0.3903-1.0244,0.3903-1.415,0l-6.2081-6.2083c-0.3897-0.3903-0.3897-1.0237,0-1.414c0.3905-0.3908,1.0244-0.3908,1.4151,0 l5.5,5.5007L33.773,16.8392c0.3906-0.3908,1.0244-0.3908,1.4153,0c0.3895,0.3903,0.3895,1.0237,0,1.414L19.7063,33.7347z"></path></symbol>
		  <symbol id="svg_xmark" viewBox="0 0 47.9998 48.0002"><path fill-rule="evenodd" clip-rule="evenodd" d="M24.0004,48.0002C10.7453,47.9997,0,37.2551,0,24.0001 C0,10.7447,10.7453,0,24.0004,0c13.2543,0,23.9994,10.7447,23.9994,24.0001C47.9998,37.2551,37.2547,47.9997,24.0004,48.0002z M39.5564,8.4436C35.5718,4.4604,30.0777,2,24.0004,1.9995C17.922,2,12.428,4.4604,8.4435,8.4436 C4.4611,12.4279,2,17.9218,1.999,24.0001C2,30.078,4.4611,35.5714,8.4435,39.5561c3.9845,3.9833,9.4785,6.4436,15.5569,6.4446 c6.0773-0.001,11.5714-2.4613,15.556-6.4446c3.9824-3.9847,6.4434-9.4781,6.4444-15.556 C45.9998,17.9218,43.5388,12.4279,39.5564,8.4436z M32.6872,32.6864c-0.3908,0.3903-1.0244,0.3903-1.4152,0l-7.293-7.2923 l-7.2921,7.2923c-0.3908,0.3903-1.0245,0.3903-1.4153,0c-0.3896-0.3908-0.3896-1.0233,0-1.4145l7.2932-7.2929l-7.2932-7.2928 c-0.3896-0.3908-0.3896-1.0233,0-1.4145c0.3908-0.3903,1.0245-0.3903,1.4153,0l7.2921,7.2928l7.293-7.2928 c0.3908-0.3903,1.0244-0.3903,1.4152,0c0.3895,0.3912,0.3895,1.0237,0,1.4145L25.394,23.979l7.2932,7.2929 C33.0767,31.6631,33.0767,32.2956,32.6872,32.6864z"></path></symbol>
		  <symbol id="svg_conversation" viewBox="0 0 70.1373 64.0266"><path d="M49.6435,17.0641H35.0932c-0.8044,0-1.4551,0.6706-1.4551,1.4995c0,0.829,0.6507,1.5002,1.4551,1.5002h14.5503 c0.8044,0,1.4551-0.6712,1.4551-1.5002C51.0986,17.7347,50.4479,17.0641,49.6435,17.0641z M42.3683,27.5621 c0-0.8289-0.6508-1.5001-1.455-1.5001H20.5428c-0.8044,0-1.455,0.6712-1.455,1.5001c0,0.8284,0.6506,1.4996,1.455,1.4996h20.3706 C41.7176,29.0616,42.3683,28.3904,42.3683,27.5621z M35.0932,35.0605H20.5428c-0.8044,0-1.455,0.6706-1.455,1.4996 c0,0.8289,0.6506,1.5001,1.455,1.5001h14.5504c0.8044,0,1.455-0.6712,1.455-1.5001 C36.5481,35.7311,35.8976,35.0605,35.0932,35.0605z M20.5428,20.0638h8.7302c0.8044,0,1.455-0.6712,1.455-1.5002 c0-0.8289-0.6506-1.4995-1.455-1.4995h-8.7302c-0.8044,0-1.455,0.6706-1.455,1.4995 C19.0878,19.3926,19.7384,20.0638,20.5428,20.0638z M49.6435,35.0605h-8.7301c-0.8044,0-1.4551,0.6706-1.4551,1.4996 c0,0.8289,0.6507,1.5001,1.4551,1.5001h8.7301c0.8044,0,1.4551-0.6712,1.4551-1.5001 C51.0986,35.7311,50.4479,35.0605,49.6435,35.0605z M49.6435,26.062h-2.9101c-0.8042,0-1.455,0.6712-1.455,1.5001 c0,0.8284,0.6508,1.4996,1.455,1.4996h2.9101c0.8044,0,1.4551-0.6712,1.4551-1.4996 C51.0986,26.7332,50.4479,26.062,49.6435,26.062z M37.1677,0.1097C17.8587-1.2277,1.2231,9.8208,0.0647,24.7685 c-0.6304,8.1697,3.3638,15.954,11.2494,21.9155c3.1154,2.3562,1.5919,5.5802-0.9017,9.8785 c-1.3323,2.2956-2.382,4.1084-1.8401,5.6722c0.1653,0.4807,0.5622,1.1382,1.5063,1.5477 c0.3853,0.1674,0.7789,0.2442,1.1926,0.2442c1.4694,0,3.2009-0.9733,5.7116-2.3824c4.6331-2.602,11.6318-6.5337,22.0593-7.3182 c16.9583-1.0879,30.0076-11.4559,31.0318-24.6546C71.2292,14.7231,56.4679,1.4622,37.1677,0.1097z M67.1581,29.4673 C66.2452,41.2706,54.3396,50.558,38.8307,51.5518c-11.1208,0.8379-18.7638,5.1325-23.3315,7.6975 c-1.6403,0.92-3.6804,2.066-4.1482,2.1319c-0.0944-0.522,0.9357-2.2993,1.6205-3.4751c2.1681-3.7433,5.4491-9.3983,0.157-13.4 c-7.2067-5.45-10.7159-12.2049-10.1483-19.5342C3.959,12.3136,17.5762,2.7782,33.9695,2.7782c0.9844,0,1.98,0.035,2.9814,0.1041 C54.645,4.1218,68.1966,16.0475,67.1581,29.4673z"></path></symbol>
		  <symbol id="svg_dashboard" viewBox="0 0 69.9985 59.9999"><path fill-rule="evenodd" clip-rule="evenodd" d="M16.0076,14.9863H7.0077v3.0258h8.9999V14.9863z M29.0077,25.0123h31.9999 V14.9864H29.0077V25.0123z M16.0076,31.012H7.0077v2.9933h8.9999V31.012z M65.625,0H4.3749C1.9582,0.0005,0,1.9467,0,4.35v51.2998 c0,2.4034,1.9582,4.349,4.3749,4.3501H65.625c2.4152-0.0011,4.3735-1.9467,4.3735-4.3501V4.35 C69.9985,1.9467,68.0402,0.0005,65.625,0z M2.9992,4.0001c0.003-0.8002,0.5688-1.0049,1.3737-1.0064h61.1605 c0.8034,0.0015,1.4532,0.621,1.4561,1.3854l0.0097,1.6205h-64V4.0001z M19.9992,56.9998h-16 c-0.8062-0.0016-1.0811-0.5497-1.084-1.35l0.084-46.6501h17V56.9998z M65.9992,56.9998H22.9991V8.9997h44.0001l0.084,46.6501 C67.0804,56.4501,66.804,56.9982,65.9992,56.9998z M16.0076,22.9992H7.0077v2.9938h8.9999V22.9992z M29.0077,34.0122h31.9999 v-3.0258H29.0077V34.0122z M29.0077,41.012h31.9999v-3.0252H29.0077V41.012z M29.0077,48.012h31.9999v-3.0252H29.0077V48.012z"></path></symbol>
		  <symbol id="svg_customers" viewBox="0 0 69.9631 57.955"><path fill-rule="evenodd" clip-rule="evenodd" d="M69.9517,48.6827l-0.0186-0.1276c-0.2678-1.4661-1.125-2.7747-2.3926-3.7465 c-1.0266-0.7961-2.3826-1.3944-3.9433-1.9195c0.0396-0.6512,0.2021-1.3955,0.5138-2.248c0.5598-0.2584,1.0227-0.6057,1.3645-0.9849 c0.6892-0.749,1.0153-1.4828,1.2903-1.8552c2.0093-2.9357,3.1673-8.0008,3.1873-15.5455c0-0.3551-0.0043-0.7024-0.0043-1.0445 v-0.0214c-0.0114-0.8254-0.0682-2.4886-1.0098-4.2455c-0.9341-1.7683-2.7743-3.5592-5.9272-4.7214 c-1.1437-0.4179-2.7274-0.6956-4.4876-0.7014c-1.3501,0.0016-2.7871,0.1711-4.1399,0.6653h0.0014 c-0.7705,0.283-1.5624,0.6465-2.3342,1.0733c-0.0014-0.1213-0.0014-0.239-0.0028-0.3609v-0.0042 c-0.0158-1.1276-0.094-3.327-1.3388-5.6503c-1.2376-2.3348-3.6616-4.7214-7.9438-6.3041C41.2678,0.3892,39.1044,0.0053,36.7233,0 c-1.8273,0.0021-3.7669,0.2343-5.5641,0.8907c-3.1218,1.1586-6.5725,3.1063-8.5108,6.2173 c-1.3616,2.2375-2.189,5.0687-2.4568,7.7665c-1.3827-1.2281-3.0433-2.1042-4.6098-2.6879l-0.0014-0.001 c-1.3575-0.4927-2.793-0.6627-4.1402-0.6643c-1.7603,0.0058-3.3426,0.2835-4.4847,0.7014c-3.153,1.1622-4.993,2.9531-5.9273,4.7214 c-0.9411,1.7569-0.9984,3.4201-1.0097,4.2455v-0.0131c-0.01,0.3766-0.0084,0.7364-0.0084,1.079 c0.0197,7.5452,1.182,12.6108,3.1913,15.5455l0,0c0.2751,0.3724,0.6011,1.1062,1.2903,1.8552 c0.3405,0.3792,0.8049,0.7265,1.3645,0.9844c0.3077,0.8546,0.4685,1.6004,0.5098,2.2506c-1.5595,0.5246-2.9122,1.1224-3.9392,1.9174 c-1.2089,0.9268-2.028,2.1643-2.3342,3.5477l-0.0044-0.001c-0.007,0.0209-0.0056,0.0319-0.0114,0.0523 c-0.0099,0.0502-0.0327,0.0972-0.0425,0.1475l0.0113,0.0021c-0.0371,0.1903-0.0441,0.3357-0.0455,0.3535 c-0.0043,0.5241,0.2307,0.9974,0.4941,1.2961c0.4713,0.5303,0.987,0.7662,1.5853,0.9964c1.7771,0.6365,4.627,0.9639,8.8537,0.9749 c1.071,0,2.2187,0.0141,3.3796,0.0314c-0.0014,0.0701-0.0199,0.1354-0.0199,0.2071c-0.0014,0.4153,0.0382,0.852,0.1266,1.3013 h-0.0014c0,0.0016,0.0014,0.0021,0.0014,0.0042c0.0014,0.0047,0,0.0094,0.0014,0.0141l0.0045-0.0005 c0.1038,0.4864,0.3459,0.7793,0.5454,0.9786c0.3943,0.3713,0.7703,0.5518,1.2218,0.7531c1.5467,0.6533,4.1245,1.2292,7.5723,1.7025 c3.4338,0.4634,7.6748,0.7845,12.3018,0.7851c5.5784-0.0016,9.7397-0.9138,12.5867-2.0775c1.4256-0.5848,2.5208-1.227,3.3255-1.9007 c0.4028-0.3389,0.7347-0.6857,0.9996-1.0785c0.1298-0.1982,0.2493-0.4121,0.3378-0.6527c1.945-0.0325,3.9274-0.0675,5.7191-0.0675 c3.2102-0.0021,5.6497-0.2082,7.3929-0.5717c0.8759-0.1867,1.5766-0.4001,2.1833-0.7265c0.3018-0.1673,0.5923-0.3645,0.8586-0.6731 c0.2622-0.2987,0.4969-0.772,0.4929-1.2961L69.9517,48.6827z M55.3926,14.908l0.0015-0.0006 c0.9085-0.3363,2.0379-0.4879,3.1301-0.4864c1.4113-0.0052,2.7898,0.261,3.465,0.5183c2.6162,0.986,3.7611,2.2412,4.3736,3.3658 c0.6067,1.1365,0.6595,2.215,0.6708,2.9274l0,0c0,0.3567,0.0041,0.6992,0.0041,1.023c0.02,7.2157-1.2461,11.9037-2.6687,13.8933 c-0.4615,0.6841-0.7308,1.2317-1.0227,1.5267c-0.2974,0.2824-0.4897,0.455-1.3145,0.5162l-0.1152,0.0021 c-0.8374,0.0147-2.7403-0.4074-4.5188-0.9665c-1.7903-0.5513-3.5733-1.2391-4.3993-1.645c-0.6381-0.308-1.2249-0.9064-1.7204-1.7228 c-0.497-0.8102-0.8844-1.8092-1.1578-2.7637l-0.0014-0.0026l-0.1026-0.3766c1.1264-3.509,1.8258-8.1201,1.9895-13.9053 C52.9799,16.0205,54.1962,15.3431,55.3926,14.908z M51.1756,41.8906c-1.5452,0.3928-3.418,1.0414-5.1427,2.0377 c-0.484-0.183-0.9983-0.3567-1.5279-0.524c-0.1041-1.2286-0.1995-2.5331-0.201-3.9934c0.6822-0.3232,1.2474-0.7469,1.6733-1.2171 c0.8818-0.9524,1.3232-1.9368,1.7432-2.5163c0.2322-0.3379,0.4458-0.7301,0.6625-1.114c0.135,0.2667,0.242,0.5403,0.4001,0.7997 c0.6848,1.1203,1.6176,2.1779,2.9295,2.8223c0.0113,0.0057,0.0298,0.0125,0.0411,0.0183 C51.5288,39.5814,51.3421,40.7755,51.1756,41.8906z M25.1362,8.6196c1.3289-2.2077,4.2726-4.0138,7.0312-5.0075 c1.3543-0.499,2.9864-0.714,4.5559-0.7119c2.0349-0.0057,3.9906,0.3667,5.0201,0.7558c3.7471,1.407,5.4759,3.259,6.3917,4.95 c0.9085,1.703,0.9826,3.3176,0.9983,4.3307v-0.0042c0.0056,0.4895,0.0099,0.9686,0.0099,1.4373 c0.0199,10.1049-1.7216,16.7009-3.8196,19.6549c-0.6053,0.8913-0.9911,1.69-1.4753,2.1889C43.3585,36.7,42.9,37.0306,41.628,37.1117 l-0.1839,0.0031c-1.3001,0.0141-3.9532-0.5863-6.4583-1.3703c-2.5194-0.7757-5.0073-1.7344-6.2037-2.3212 c-1.0196-0.4948-1.904-1.4175-2.6317-2.6131c-0.7277-1.1894-1.2804-2.622-1.6721-3.9834v0.0005 c-1.219-4.2402-1.4225-7.1137-1.4896-9.9815l-0.0029-0.0701l-0.0027-0.1993C22.9704,14.0084,23.8304,10.7195,25.1362,8.6196z M22.9858,43.4095c-1.4484-0.7066-2.9351-1.2035-4.1942-1.5252c-0.168-1.1125-0.3544-2.3039-0.5781-3.68 c0.0114-0.0058,0.03-0.0131,0.0415-0.0188c1.3116-0.6444,2.2443-1.702,2.9294-2.8223c0.6849-1.1266,1.1408-2.3453,1.4668-3.4672 v-0.0005c0.1083-0.3745,0.1766-0.704,0.2664-1.056c0.2336,0.4963,0.4485,0.999,0.7376,1.4749 c0.7591,1.2396,1.7473,2.3798,3.0208,3.2141c0.0197,2.7297,0.0568,4.9327,0.1224,6.667 C25.6376,42.4858,24.3388,42.888,22.9858,43.4095z M2.9252,22.2555c0-0.3426,0.0016-0.6789,0.0084-1.0094v-0.0136 c0.0115-0.7124,0.0643-1.7909,0.6709-2.9274c0.6126-1.1246,1.7576-2.3798,4.375-3.3663c0.6723-0.2568,2.0493-0.523,3.4607-0.5178 c1.0896-0.0015,2.216,0.1501,3.1345,0.487c1.9326,0.6914,3.9748,1.9687,4.8437,3.4279v0.0011 c0.3203,0.5204,0.611,1.1627,0.8459,1.8525c0.1169,1.3186,0.2904,2.7088,0.621,4.2884c-0.0614,1.8965-0.2364,3.827-1.0382,6.6184 v-0.0005c-0.2735,0.9545-0.6609,1.9535-1.1578,2.7637c-0.4955,0.8164-1.0825,1.4148-1.7206,1.7233 c-0.826,0.4054-2.6104,1.0932-4.4019,1.6445c-1.7774,0.5591-3.6814,0.9812-4.5189,0.9665l-0.1095-0.0021 c-0.8274-0.0612-1.0199-0.2338-1.3175-0.5162c-0.2919-0.295-0.5612-0.8426-1.0225-1.5267v-0.0006 C4.1727,34.1581,2.9055,29.4712,2.9252,22.2555z M10.9332,49.2779C7.857,49.28,5.5585,49.0687,4.1386,48.769 c-0.463-0.0952-0.789-0.1988-1.0425-0.2934c0.205-0.4818,0.5426-0.9174,1.128-1.3835c0.8218-0.6433,2.1433-1.2699,4.0162-1.796 c0.5839-0.1648,1.0039-0.6711,1.0552-1.2731l0.0298-0.7406c0.0014-0.7166-0.1109-1.476-0.299-2.2653 c1.3303-0.1537,2.8583-0.5512,4.4063-1.0209c0.6979-0.216,1.3673-0.4451,2.0066-0.6742c0.2394,1.477,0.4303,2.7292,0.6097,3.951 c0.0882,0.6025,0.5413,1.0816,1.1406,1.2087c0.6368,0.1323,1.4285,0.341,2.2545,0.6114c-1.3002,0.771-2.5178,1.6763-3.4594,2.8254 c-0.3503,0.4263-0.6423,0.9033-0.9012,1.4018C13.6676,49.2978,12.2533,49.2779,10.9332,49.2779z M49.6091,52.1263 c-1.8999,1.2961-6.3904,2.9389-13.5424,2.9285c-5.4731,0.0005-10.4064-0.4666-13.948-1.0681 c-1.769-0.2986-3.1944-0.636-4.1216-0.9414c-0.3389-0.1099-0.5784-0.2108-0.7562-0.2945l-0.0328-0.3342 c0.0056-0.9781,0.3547-1.8196,1.0425-2.6711c1.0211-1.2679,2.844-2.4101,4.8078-3.2559c1.9598-0.8525,4.0449-1.4326,5.5486-1.748 c0.7007-0.1475,1.1892-0.7808,1.1536-1.4927c-0.0784-1.5408-0.1283-3.6455-0.1567-6.3213c1.3173,0.5209,2.8754,1.0774,4.516,1.5863 c2.6518,0.8086,5.3107,1.4771,7.2888,1.498c0.03,1.7255,0.151,3.2851,0.2662,4.6037c0.0513,0.5978,0.4742,1.1041,1.0556,1.2683 c2.6488,0.7454,4.5529,1.6361,5.7834,2.599c1.1407,0.9001,1.7103,1.8018,1.9767,2.8693 C50.3893,51.4929,50.1318,51.7832,49.6091,52.1263z M59.0354,49.2779c-1.9596,0-4.1071,0.0408-6.1765,0.0748 c-0.5499-1.1941-1.3986-2.2705-2.5463-3.1534c-0.3007-0.2332-0.641-0.4451-0.9785-0.659c1.2363-0.4943,2.5036-0.8651,3.4437-1.0586 c0.5982-0.1261,1.0523-0.6078,1.1407-1.2103c0.178-1.2202,0.3704-2.4718,0.6081-3.9489c0.6409,0.2286,1.3088,0.4577,2.0067,0.6737 c1.5453,0.4697,3.0733,0.8672,4.4047,1.0209c-0.1892,0.7903-0.3018,1.5508-0.3004,2.2653c0,0.2631,0.0129,0.5141,0.0356,0.7505 c0.0542,0.5973,0.4728,1.0989,1.0537,1.2632c1.8729,0.5261,3.1947,1.1527,4.0163,1.796c0.5854,0.4661,0.9229,0.9017,1.1279,1.3835 c-0.074,0.0287-0.1225,0.0544-0.2149,0.0816C65.437,48.9499,62.8123,49.2847,59.0354,49.2779z"></path></symbol>
		  <symbol id="svg_auth" viewBox="0 0 24 24"><path d="M14.9766,9.9746c0-1.6406-1.334-2.9751-2.9746-2.9751S9.0264,8.334,9.0264,9.9746 c0,0.9175,0.4336,1.7866,1.1504,2.3462l-1.1387,5.062c-0.0332,0.1484,0.0029,0.3037,0.0977,0.4224s0.2383,0.1875,0.3906,0.1875 h4.9502c0.1523,0,0.2959-0.0693,0.3906-0.188s0.1309-0.2744,0.0967-0.4224l-1.1465-5.0552 C14.54,11.7681,14.9766,10.897,14.9766,9.9746z M10.1514,16.9927l1.0762-4.7822c0.0469-0.2114-0.0469-0.4287-0.2324-0.5396 c-0.6064-0.3608-0.9688-0.9951-0.9688-1.6963c0-1.0889,0.8867-1.9751,1.9756-1.9751s1.9746,0.8862,1.9746,1.9751 c0,0.6948-0.374,1.3462-0.9756,1.7007c-0.1875,0.1104-0.2822,0.3291-0.2334,0.541l1.083,4.7764H10.1514z"></path><path d="M12,0C5.3828,0,0,5.3833,0,12s5.3828,12,12,12s12-5.3833,12-12S18.6172,0,12,0z M12,23 C5.9346,23,1,18.0654,1,12S5.9346,1,12,1s11,4.9346,11,11S18.0654,23,12,23z"></path></symbol>
		  <symbol id="svg_bill" viewBox="0 0 76 48.9768"><g><path d="M75.1621,0.8357c-0.4277-0.2759-1.0439-0.314-1.5078-0.1055c-0.1494,0.0679-15.2095,6.7192-35.2075,2.2319 C17.6323-1.7068,2.1624,0.5159,1.5247,0.613C0.7913,0.7244,0,1.3547,0,2.096v42.1377c0,0.4678,0.4502,0.9082,0.8218,1.1924 c0.3721,0.2832,0.9709,0.3789,1.4226,0.2539c0.145-0.041,14.7379-3.9004,35.4215,1.1758c6.373,1.5645,12.188,2.1211,17.1939,2.1211 c11.9609,0,19.6346-3.1768,20.073-3.3672C75.4807,45.3713,76,44.8313,76,44.2337V2.096C76,1.5862,75.5898,1.1121,75.1621,0.8357z M73,43.2005c-4,1.2266-16.7148,5.0879-34.4111,0.7412c-8.5332-2.0938-16.3105-2.7344-22.2583-2.7344 C10.2007,41.2073,6,41.888,3,42.3577V3.427c5-0.4214,17.7744-1.3276,34.6724,2.4629C54.4507,9.6536,68,6.0505,73,4.2927V43.2005z"></path><path d="M38.0811,9.3948c-8.3228,0-15.0938,6.7705-15.0938,15.0928s6.771,15.0928,15.0938,15.0928 c8.3223,0,15.0928-6.7705,15.0928-15.0928S46.4033,9.3948,38.0811,9.3948z M25.9873,24.4876 c0-6.668,5.4253-12.0928,12.0938-12.0928c6.668,0,12.0928,5.4248,12.0928,12.0928S44.749,36.5803,38.0811,36.5803 C31.4126,36.5803,25.9873,31.1555,25.9873,24.4876z"></path><ellipse cx="38.0806" cy="24.4876" rx="4.232" ry="6.299"></ellipse></g></symbol>
		  <symbol id="svg_billstack" viewBox="0 0 71.9684 48.0013"><path fill-rule="evenodd" clip-rule="evenodd" d="M70.9554,16.5353c0.7833-0.2688,1.2007-1.1228,0.9311-1.9072 c-0.2678-0.7844-1.1215-1.2021-1.9047-0.933l-16.0131,5.4996v-4.6312L70.9554,8.73c0.6297-0.2163,1.0381-0.8162,1.0118-1.4823 c-0.0279-0.6661-0.4861-1.23-1.1305-1.3934L47.7944,0l-0.7952,0.016L1.0724,13.6758c-0.6252,0.1862-1.057,0.7535-1.0717,1.4063 c-0.0146,0.6529,0.3926,1.2385,1.0088,1.4523l23.0425,7.968c0.3149,0.1093,0.6603,0.1096,0.9766,0.0012l13.7951-4.7374 l-0.0015,4.6314l-14.2796,4.9033L1.9891,21.5016c-0.7832-0.2706-1.6369,0.1456-1.9062,0.9294 c-0.2711,0.7838,0.1448,1.6384,0.9281,1.909H1.0095l23.0425,7.968c0.3149,0.1094,0.6603,0.1094,0.9766,0.0012l13.7921-4.7368 l-0.003,4.6317l-14.2751,4.9024L1.9891,29.3069c-0.7832-0.2706-1.6369,0.1456-1.9062,0.9297 c-0.2711,0.7838,0.1448,1.6384,0.9281,1.909H1.0095l23.0425,7.9681c0.3149,0.1093,0.6603,0.1093,0.9766,0.0009l13.7876-4.7357 l-0.0015,4.6312l-14.2736,4.9023l-22.552-7.7999c-0.7832-0.2706-1.6369,0.1456-1.9062,0.9297 c-0.2711,0.7838,0.1448,1.6384,0.9281,1.909H1.0095l23.0425,7.9681c0.3149,0.109,0.6603,0.1093,0.9766,0.0009l15.773-5.4174 l30.1538-10.3563c0.7818-0.2688,1.1992-1.1228,0.9311-1.9072c-0.2678-0.7844-1.1215-1.2021-1.9032-0.9333l-16.0146,5.4999V30.175 l16.9867-5.8341c0.7833-0.2691,1.2007-1.1228,0.9311-1.9072c-0.2678-0.7844-1.1215-1.2024-1.9047-0.9333L53.9687,27v-4.6303 L70.9554,16.5353z M47.4577,3.0123l17.7612,4.5126l-12.5869,4.323L36.3301,6.3216L47.4577,3.0123z M24.5426,21.4953L6.4035,15.2227 l12.2766-3.6513l17.0893,6.069L24.5426,21.4953z M41.8133,38.9803l0.0015-5.5993c0.0015-0.0018,0-0.0036,0-0.0036l0.006-15.713 c0-0.03-0.0234-0.052-0.0264-0.0817c-0.006-0.1354-0.006-0.2715-0.0528-0.4063c-0.0366-0.1078-0.1083-0.1901-0.1655-0.2832 c-0.0276-0.0447-0.0438-0.088-0.0747-0.1297c-0.1667-0.2189-0.3805-0.3799-0.6309-0.4793 c-0.0192-0.0075-0.0279-0.0285-0.0468-0.0354L23.563,10.1191l7.7863-2.3162l19.6221,6.6528v21.3796L41.8133,38.9803z"></path></symbol>
		  <symbol id="svg_store" viewBox="0 0 24 20.999"><g><path d="M23.5,19.999h-1.4883V8.8058c1.1836-0.4269,1.959-1.5849,1.959-2.9621 c0-0.0754-0.1035-0.4099-0.1318-0.5098C23.3979,3.5952,21.9546,0,21.6455,0H2.3252c-0.3091,0-1.752,3.5952-2.1929,5.3339 C0.104,5.4338,0,5.7682,0,5.8437c0,1.3796,0.7988,2.539,1.9946,2.9641V19.999H0.5c-0.2764,0-0.5,0.2236-0.5,0.5s0.2236,0.5,0.5,0.5 H5h14h4.5c0.2764,0,0.5-0.2236,0.5-0.5S23.7764,19.999,23.5,19.999z M11.1245,5.999c-0.0254,0.0485-0.0576,0.0925-0.0757,0.1459 c-0.2944,0.8879-1.1631,1.8463-2.0527,1.8463c-0.7793,0-1.6982-0.988-2.0679-1.9107C6.9165,6.0506,6.895,6.0273,6.8804,5.999 H11.1245z M17.1299,5.999c-0.0215,0.0399-0.0493,0.0748-0.0654,0.118c-0.3301,0.9052-1.2373,1.8742-2.0605,1.8742 c-0.8916,0-1.7617-0.9586-2.0566-1.8466c-0.0181-0.0532-0.0503-0.0972-0.0757-0.1456H17.1299z M22.9614,5.999 c-0.0669,1.1622-0.8647,1.9922-1.9536,1.9922c-0.8257,0-1.7339-0.9691-2.0645-1.8742c-0.0156-0.0432-0.0439-0.0781-0.0654-0.118 H22.9614z M5.1191,5.999C5.105,6.027,5.084,6.0502,5.0718,6.0798C4.7095,6.9839,3.7676,7.9912,2.9961,7.9912 c-1.0884,0-1.916-0.847-1.9863-1.9922H5.1191z M6,19.999v-8h12v8H6z M5,10.999v9H2.9946V8.9911 c0.0005,0,0.001,0.0001,0.0015,0.0001C4.3208,8.9912,5.5352,7.611,6,6.4521C6.4639,7.611,7.6719,8.9912,8.9961,8.9912 c1.3911,0,2.5864-1.2795,3.002-2.5312c0.416,1.2517,1.6147,2.5312,3.0059,2.5312c1.3589,0,2.5596-1.3248,3-2.5312 c0.4404,1.2064,1.6455,2.5312,3.0039,2.5312c0.0015,0,0.0024-0.0004,0.0039-0.0004V19.999H19v-9H5z"></path><path d="M15.5,13.9912H8.4585c-0.2764,0-0.5,0.2236-0.5,0.5s0.2236,0.5,0.5,0.5H15.5c0.2764,0,0.5-0.2236,0.5-0.5 S15.7764,13.9912,15.5,13.9912z"></path><path d="M15.5,16.9912H8.4585c-0.2764,0-0.5,0.2236-0.5,0.5s0.2236,0.5,0.5,0.5H15.5c0.2764,0,0.5-0.2236,0.5-0.5 S15.7764,16.9912,15.5,16.9912z"></path></g></symbol>
		  <symbol id="svg_heart" viewBox="0 0 24 24"><g><path d="M22.5,0h-21C0.6729,0,0,0.6729,0,1.5v21C0,23.3271,0.6729,24,1.5,24h21c0.8271,0,1.5-0.6729,1.5-1.5v-21 C24,0.6729,23.3271,0,22.5,0z M23,22.5c0,0.2759-0.2246,0.5-0.5,0.5h-21C1.2246,23,1,22.7759,1,22.5v-21C1,1.2241,1.2246,1,1.5,1 h21C22.7754,1,23,1.2241,23,1.5V22.5z"></path><path d="M15.6597,5.0159c-1.5483,0-2.9033,0.8134-3.6709,2.0336c-0.7676-1.2202-2.1226-2.0336-3.6709-2.0336 c-2.3955,0-4.3379,1.9422-4.3379,4.338c0,4.3706,7.7124,10.3355,8.0024,10.3355s8.0151-5.9649,8.0151-10.3355 C19.9976,6.9581,18.0552,5.0159,15.6597,5.0159z M11.9829,18.5026C10.3154,17.2555,4.98,12.5314,4.98,9.3539 c0-1.8406,1.4976-3.338,3.3379-3.338c1.1519,0,2.2075,0.5854,2.8242,1.566l0.8467,1.3455l0.8467-1.3455 c0.6167-0.9806,1.6724-1.566,2.8242-1.566c1.8403,0,3.3379,1.4974,3.3379,3.338C18.9976,12.5313,13.6523,17.2559,11.9829,18.5026z"></path></g></symbol>
		  <symbol id="svg_settings" viewBox="0 0 24 24"><g><path fill-rule="evenodd" clip-rule="evenodd" d="M12,0C5.3828,0,0,5.3833,0,12s5.3828,12,12,12s12-5.3833,12-12S18.6172,0,12,0z M12,23 C5.9346,23,1,18.0654,1,12S5.9346,1,12,1s11,4.9346,11,11S18.0654,23,12,23z"></path><path fill-rule="evenodd" clip-rule="evenodd" d="M10,8.9999H9V5.5C9,5.2236,8.7764,5,8.5,5S8,5.2236,8,5.5v3.4999H7c-0.5522,0-1,0.4477-1,1 c0,0.5522,0.4478,1,1,1h1V18.5C8,18.7764,8.2236,19,8.5,19S9,18.7764,9,18.5v-7.5001h1c0.5522,0,1-0.4478,1-1 C11,9.4476,10.5522,8.9999,10,8.9999z"></path><path d="M17,12.9999h-1V5.5C16,5.2236,15.7764,5,15.5,5S15,5.2236,15,5.5v7.4999h-1c-0.5522,0-1,0.4477-1,1 c0,0.5522,0.4478,1,1,1h1V18.5c0,0.2764,0.2236,0.5,0.5,0.5s0.5-0.2236,0.5-0.5v-3.5001h1c0.5522,0,1-0.4478,1-1 C18,13.4476,17.5522,12.9999,17,12.9999z"></path> </g></symbol>
		  <symbol id="svg_play" viewBox="0 0 48 48"><path d="M45.79,20.45l-40-20A4,4,0,0,0,0,4V44a4,4,0,0,0,5.79,3.58l40-20A4,4,0,0,0,45.79,20.45Z"></path></symbol>
		  <symbol id="svg_search" viewBox="0 0 32 32"><path d="M31.8102,30.4075c-0.0632-0.0981-0.1128-0.1534-0.1453-0.1877l0.0006-0.0004 l-8.823-10.0076c1.5659-2.108,2.5032-4.7108,2.5032-7.5385c0-6.9998-5.674-12.673-12.6724-12.6733C5.6735,0.0003,0,5.6734,0,12.6733 c0,6.9994,5.6735,12.6725,12.6734,12.6729c2.8334,0,5.4416-0.9416,7.5519-2.5135l10.0052,8.8208V31.653 c0.0358,0.0335,0.0893,0.081,0.1817,0.1429c0.1258,0.0787,0.3127,0.1895,0.613,0.1948c0.2248,0.0064,0.5055-0.1003,0.6833-0.2856 l0.0066-0.0064c0.183-0.1775,0.2911-0.4532,0.2846-0.6831C31.9945,30.7191,31.887,30.5333,31.8102,30.4075z M4.6547,20.6912 c-2.0532-2.0543-3.3206-4.8846-3.3213-8.0179c0.0007-3.1336,1.2682-5.964,3.3213-8.0183c2.0546-2.0531,4.8846-3.3209,8.0187-3.3209 c3.1324,0,5.9633,1.2679,8.0177,3.3209c2.0526,2.0543,3.3208,4.8849,3.3214,8.0183c-0.0006,3.1332-1.2689,5.9636-3.3214,8.0179 c-2.0544,2.053-4.8852,3.3208-8.0177,3.3212C9.5394,24.012,6.7093,22.7441,4.6547,20.6912z"></path></symbol>
		</svg>

		<section id="hero">
      <div class="inner">
        <h2>
					<svg>
          	<use xmlns:xlink="http://www.w3.org/1999/xlink" xlink:href="#svg_plasso_logo"></use>
          </svg>
				</h2>
        <p class="tagline">
          Sell anything with WordPress
          <br>
          using Plasso and simple shortcodes.
        </p>
        <a href="#get-started" class="btn scroll">Get Started</a>
	    </div>
		</section>

		<section class="page narrow" id="get-started">
      <h3>1. Sign Up</h3>

      <p class="subhead">
        Extend the power of any WordPress website with commerce tools powered by Plasso — together a complete solution to sell virtually anything and grow your audience. To get started, create a new Plasso account, or if you already have one, log in.
      </p>

			<article class="actions">
				<a href="https://plasso.com/signup" target="_blank" class="btn small">Sign Up</a>
				<a href="https://plasso.com/login" target="_blank" class="btn empty small">Log In</a>
			</article>
    </section>

		<section class="page narrow">
      <h3>2. Create a Space</h3>

      <p class="subhead">
        Plasso has a growing selection tools and products to help you sell virtually anything website.
      </p>

			<article>
				<h4>Membership</h4>

				<p>
					You’ll have customers signing up for your new business in just a few minutes. Plasso handles all the technical details like recurring billing, member management and more.
				</p>

				<a href="https://plasso.com/app/" target="_blank" class="btn outline small membership">Create a Space</a>
			</article>

			<article>
	      <h4>Storefront</h4>

				<p>
					Powerful and easy one-off product sales. Sell physical and digital goods, charge for services, accept donations, sell pre-orders and more. Storefront makes it all too easy.
				</p>

				<a href="https://plasso.com/app/" target="_blank" class="btn outline small storefront">Create a Space</a>
				<a href="#protected-pages" class="scroll btn empty small storefront">Forward Settings</a>
			</article>

			<article>
				<h4>Billing</h4>

				<p>
					An entire customer billing, management, storage and authentication system ready to be embedded into your website. Instantly create a pay-wall on your website using your own content. You control the customer experience, Plasso takes care of the rest.
				</p>

				<a href="https://plasso.com/app/" target="_blank" class="btn outline small billing">Create a Space</a>
				<a href="#protected-pages" class="scroll btn empty small billing">Forward Settings</a>
			</article>
    </section>

		<section class="page narrow">
      <h3>3. Add a Button</h3>

			<p class="subhead">
        Plasso has a growing selection tools and products to help you sell virtually anything website.
      </p>

			<article>
				<h4>Posts</h4>

				<p>
					You can add a Plasso checkout button in any post — just click the Plasso icon in the post editor to insert the shortcode and then add your Space ID.
				</p>

				<a href="<?php echo admin_url('edit.php'); ?>" class="btn outline small">Add a Button</a>
			</article>

			<article>
				<h4>Pages</h4>

				<p>
					You can add a Plasso checkout button in any page — just click the Plasso icon in the post editor to insert the shortcode and then add your Space ID.
				</p>

				<a href="<?php echo admin_url('edit.php?post_type=page'); ?>" class="btn outline small">Add a Button</a>
			</article>

			<article>
				<h4>Theme</h4>

				<p>
					You can manually add a Plasso checkout button to any of your theme files by using the short snippet below.
				</p>

				<pre><code>&lt;?php echo do_shortcode("[plasso id='SpaceID' text='Button Text']"); ?&gt;</code></pre>
			</article>
    </section>

		<section class="page narrow form" id="protected-pages">
      <h3>Forward URL Settings</h3>

			<p class="subhead">
        If you’re using a <strong class="storefront">Storefront</strong> or <strong class="billing">Billing</strong> space, you can set a Forward URL users will be redirected to after they finish checking out or logging in. This page is protected and can only be viewed by your customers.
      </p>

			<form method="post" action="options.php">
				<ul>
					<?php

						// No fontpage allowed for the protected page.
						$frontpage_id = get_option('page_on_front');

						// Loop through the pages, make a radio list.
						if($pages = get_pages()){
							foreach($pages as $page){
								if($page->ID != $frontpage_id) {
									echo '<li>';
									echo '<input type="radio" id="' . $page->ID . '" name="plasso_settings[plasso_select_protected_pages]" value="' . $page->ID . '" ' . checked($page->ID, $plasso_options['plasso_select_protected_pages'], false) . '>';
									echo '<label for="' . $page->ID . '">' . $page->post_title . '</label>';
									echo '<div class="check"></div>';
									echo '</li>';
								}
							}
						}
					?>
				</ul>

				<?php
					settings_fields('plasso_plugin_page');
					do_settings_sections('plasso_plugin_page');
				?>

				<input type="submit" class="btn small outline" value="Save Changes" />
			</form>
    </section>

		<section class="page narrow">
      <h3>Advanced Configuration</h3>

			<p class="subhead">
				Configure your Plasso shortcode buttons using any combination of the attributes and options below to customize the checkout experience.
			</p>

			<article>
				<h4>View</h4>

				<p>
					Add the “view” attribute to your shortcode to change the view of the checkout overlay. For instance, if you wanted to add a login button, add view='login' to your shortcode like this:
				</p>

				<pre><code>[plasso id='SpaceID' <strong>view='login'</strong> text='Button Text']</code></pre>
			</article>

			<article>
				<h4>Preselect</h4>

				<p>
					Add the “preselect” attribute to your shortcode to change the preselected product of the checkout overlay. For instance, if you wanted to preselect "Some Product" which has an ID of "1234", add preselect='1234' to your shortcode like this:
				</p>

				<pre><code>[plasso id='SpaceID' <strong>preselect='1234'</strong> text='Button Text']</code></pre>
			</article>

			<article>
				<h4>Class</h4>

				<p>
					Add the “class” attribute to your shortcode to change the default CSS class for your button. For instance, if your theme has a pre-styled class for buttons (e.g. “button-class”), add class='button-class' to your shortcode like this:
				</p>

				<pre><code>[plasso id='SpaceID' text='Button Text' <strong>class='button-class'</strong>]</code></pre>
			</article>

			<article>
				<h4>Overlay</h4>

				<p>
					Add the “overlay” attribute to your shortcode to change the background color of the checkout overlay. For instance, if you wanted to change the overlay color to black add overlay='#000000' to your shortcode like this:
				</p>

				<pre><code>[plasso id='SpaceID' text='Button Text' <strong>overlay='#000000'</strong>]</code></pre>
			</article>
    </section>

    <section class="page narrow">
      <h3>Plasso Themes</h3>

			<p class="subhead">
				If you haven’t decided on a theme already, we have a growing library of simple WordPress themes specifically designed for Plasso.
			</p>

			<article class="actions">
				<a href="https://plasso.com/wordpress" target="_blank" class="btn outline small">View Our Themes</a>
			</article>

			<img src="<?php echo plugin_dir_url( __FILE__ ) . 'assets/images/plasso-themes.jpg' ?>" alt="Plasso Themes">
    </section>
	</div>
<?php }
